@@ -351,6 +351,36 @@ class MessageProcessor:
         tracker.model_id = self.model_metadata.model_id
         return tracker
 
+    async def fetch_full_tracker_with_initial_session(
+        self,
+        conversation_id: Text,
+        output_channel: Optional[OutputChannel] = None,
+        metadata: Optional[Dict] = None,
+    ) -> DialogueStateTracker:
+        """Get the full tracker for a conversation, including events after a restart.
+
+        Args:
+            conversation_id: The ID of the conversation for which the history should be
+                retrieved.
+            output_channel: Output channel associated with the incoming user message.
+            metadata: Data sent from client associated with the incoming user message.
+
+        Returns:
+            Tracker for the conversation. Creates an empty tracker with a new session
+            initialized in case it's a new conversation.
+        """
+        conversation_id = conversation_id or DEFAULT_SENDER_ID
+
+        tracker = await self.tracker_store.get_or_create_full_tracker(
+            conversation_id, False
+        )
+        tracker.model_id = self.model_metadata.model_id
+
+        if not tracker.events:
+            await self._update_tracker_session(tracker, output_channel, metadata)
+
+        return tracker
+
     async def get_trackers_for_all_conversation_sessions(
         self, conversation_id: Text
     ) -> List[DialogueStateTracker]:
